<?php

namespace Drupal\entity_echo\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\entity_echo\EntityCloner;

/**
 * Form to clone an entity.
 */
class EntityCloneForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity cloner service.
   *
   * @var \Drupal\entity_echo\EntityCloner
   */
  protected $entityCloner;

  /**
   * Constructs an EntityCloneForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\entity_echo\EntityCloner $entity_cloner
   *   The entity cloner service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, EntityCloner $entity_cloner) {
    $this->entityTypeManager = $entity_type_manager;
    $this->entityCloner = $entity_cloner;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_echo.cloner')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_clone_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Debug raw node parameter.
    $entity = NULL;
    $raw_node = $this->getRequest()->attributes->get('node');
    if (!empty($raw_node)) {
      $entity = $raw_node;
    }

    if (empty($entity)) {
      $entity = $this->getRequest()->attributes->get('taxonomy_term');
    }

    if (empty($entity)) {
      throw new \InvalidArgumentException('An entity is required to clone.');
    }

    $form['#title'] = $this->t('Clone @label', ['@label' => $entity->label()]);

    $form['actions'] = [
      '#type' => 'actions',
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Clone Entity'),
      '#button_type' => 'primary',
    ];

    $form_state->set('entity', $entity);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $entity = $form_state->get('entity');
    $this->entityCloner->cloneEntity($entity);
  }

}
