<?php

namespace Drupal\entity_echo\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\entity_echo\EntityCloner;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form to import a node from JSON.
 */
class EntityImportForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity cloner service.
   *
   * @var \Drupal\entity_echo\EntityCloner
   */
  protected $entityCloner;

  public function __construct(EntityTypeManagerInterface $entityTypeManager, EntityCloner $entityCloner) {
    $this->entityTypeManager = $entityTypeManager;
    $this->entityCloner = $entityCloner;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('entity_echo.cloner')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_echo_import_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['json'] = [
      '#type' => 'textarea',
      '#title' => $this->t('JSON Data'),
      '#description' => $this->t('Paste the JSON data for the node to import.'),
      '#required' => TRUE,
      '#rows' => 10,
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Import Entity'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $json = $form_state->getValue('json');
    try {
      $this->entityCloner->importEntity($json);
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t('Error importing Entity : @message', ['@message' => $e->getMessage()]));
    }
  }

}
